@@ -1,7 +1,7 @@
 package Perinci::Examples::Tiny;
 
-our $DATE = '2015-11-27'; # DATE
-our $VERSION = '0.62'; # VERSION
+our $DATE = '2015-11-28'; # DATE
+our $VERSION = '0.63'; # VERSION
 
 our %SPEC;
 
@@ -14,6 +14,16 @@ sub noop {
     [200];
 }
 
+# this Rinci metadata is already normalized
+$SPEC{hello_naked} = {
+    v => 1.1,
+    summary => "Hello world",
+    result_naked => 1,
+};
+sub hello_naked {
+    "Hello, world";
+}
+
 # this Rinci metadata is already normalized
 $SPEC{odd_even} = {
     v => 1.1,
@@ -50,7 +60,7 @@ Perinci::Examples::Tiny - Small examples
 
 =head1 VERSION
 
-This document describes version 0.62 of Perinci::Examples::Tiny (from Perl distribution Perinci-Examples), released on 2015-11-27.
+This document describes version 0.63 of Perinci::Examples::Tiny (from Perl distribution Perinci-Examples), released on 2015-11-28.
 
 =head1 DESCRIPTION
 
@@ -60,6 +70,17 @@ benchmarking startup overhead of L<Perinci::CmdLine::Inline>-generated scripts.
 =head1 FUNCTIONS
 
 
+=head2 hello_naked() -> any
+
+Hello world.
+
+This function is not exportable.
+
+No arguments.
+
+Return value:  (any)
+
+
 =head2 noop() -> [status, msg, result, meta]
 
 Do nothing.
@@ -113,7 +134,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Ex
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-Examples>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-Examples>.
 
 =head1 BUGS
 
